<?php
/**
 * @package WordPress
 * @subpackage listio
 */

if( !function_exists('listio_admin_amenities') ): 
    function listio_admin_amenities() {
        add_settings_section( 'listio_amenities_section', __( 'Amenities', 'listio' ), 'listio_amenities_section_callback', 'listio_amenity_settings' );
    }
endif;

if( !function_exists('listio_amenities_section_callback') ): 
    function listio_amenities_section_callback() { 
        wp_nonce_field('add_amenities_ajax_nonce', 'securityAddAmenities', true);

        print '<h4>' . __('Add New Amenity', 'listio') . '</h4>';
        print '<table class="form-table">
            <tbody>
                <tr>
                    <th scope="row">' . __('Amenity ID', 'listio') . '</th>
                    <td>
                        <input type="text" size="40" name="amenity_name" id="amenity_name">
                        <p class="help">' . __('Insert the amenity unique ID. <br /><strong>Ex: personal_elevator</strong>', 'listio') . '</p>
                    </td>
                </tr>
                <tr>
                    <th scope="row">' . __('Amenity label', 'listio') . '</th>
                    <td>
                        <input type="text" size="40" name="amenity_label" id="amenity_label"><br>
                        <p class="help">' . __('This value will be displayed as a label of that field. <br /><strong>Ex: Personal Elevator</strong>', 'listio') . '</p>
                    </td>
                </tr>
                <tr>
                    <th scope="row">' . __('Amenity icon', 'listio') . '</th>
                    <td>
                        <div class="dropdown">
                            <a class="button button-secondary">' . __('Select an icon', 'listio') . '&nbsp;&nbsp;&nbsp;<span class="fa fa-caret-down"></span></a>
                            <ul class="dropdown-menu iconsMenu"></ul>
                            <input type="hidden" name="amenity_icon" id="amenity_icon" class="iconsField">
							 <p class="help">' . __('Select this fontawesome icon.', 'listio') . '</p>
                        </div>
                        <div class="dropdown-backdrop"></div>
                    </td>
                </tr>
				<tr>
                    <th scope="row">' . __('Custom Icon', 'listio') . '</th>
                    <td>
                        <input type="text" size="40" name="icon_image" id="icon_image">
                        <input id="slide_image_btn" type="button"  class="slide_image_btn button" value="' . __('Browse...', 'listio') . '" />
						<p class="help">' . __('Upload custom icon.', 'listio') . '</p>
                    </td>
                </tr>			
				
                <tr>
                    <th scope="row">' . __('Position', 'listio') . '</th>
                    <td>
                        <input type="text" size="4" name="amenity_position" id="amenity_position" value="0">
                    </td>
                </tr>
            </tbody>
        </table>';
        print '<p class="submit"><input type="button" name="add_amenity_btn" id="add_amenity_btn" class="button button-secondary" value="' . __('Add Amenity', 'listio') . '">&nbsp;&nbsp;&nbsp;<span class="fa fa-spin fa-spinner preloader"></span></p>';

        print '<h4>' . __('Amenities List', 'listio') . '</h4>';
        print '<table class="table table-hover" id="amenitiesTable">
            <thead>
                <tr>
                    <th>' . __('Field name', 'listio') . '</th>
                    <th>' . __('Amenity label', 'listio') . '</th>
                    <th>' . __('Amenity icon', 'listio') . '</th>
                    <th>' . __('Position', 'listio') . '</th>
                    <th>&nbsp;</th>
                </tr>
            </thead>
            <tbody>';

        $options = get_option('listio_amenity_settings');
        if(is_array($options)) {
            uasort($options, "listio_compare_position");
			
            foreach ($options as $key => $value) {

                print '<tr>
                    <td><input type="text" name="listio_amenity_settings[' . $key . '][name]" value="' . $value['name'] . '"></td>
                    <td><input type="text" name="listio_amenity_settings[' . $key . '][label]" value="' . $value['label'] . '"></td>';
				if(isset($value['image'])){	
					print'<td><img src="' . $value['image'] . '"></td>';
					print'<input type="hidden" name="listio_amenity_settings[' . $key . '][image]" value="' .$value['image']. '">';
					
				}elseif(isset($value['icon']) && $value['icon'] != ''){
					print'<td>
							<div class="dropdown">
								<a class="button button-secondary">' . __('Select an icon', 'listio') . '&nbsp;&nbsp;&nbsp;<span class="fa fa-caret-down"></span></a>
								<ul class="dropdown-menu iconsMenu"></ul>
								<input type="hidden" name="listio_amenity_settings[' . $key . '][icon]" class="iconsField" value="' .$value['icon']. '">
							</div>
							<div class="dropdown-backdrop"></div>
						</td>';
				}
                print ' <td><input type="text" size="4" name="listio_amenity_settings[' . $key . '][position]" value="' . $value['position'] . '"></td>
                    <td><a href="javascript:void(0);" data-row="' . $key . '" class="delete-amenity">' . __('Delete', 'listio') . ' <span class="fa fa-spin fa-spinner preloader"></span></a></td>
                </tr>';
            }
        }

        print '</tbody></table>';
    }
endif;

if( !function_exists('listio_add_amenities') ): 
    function listio_add_amenities () {
        check_ajax_referer('add_amenities_ajax_nonce', 'security');
        $name        = isset($_POST['name']) ? sanitize_text_field($_POST['name']) : '';
        $label       = isset($_POST['label']) ? sanitize_text_field($_POST['label']) : '';
		$image    	 = isset($_POST['image']) ? sanitize_text_field($_POST['image']) : '';
        $icon        = isset($_POST['icon']) ? sanitize_text_field($_POST['icon']) : '';
        $position    = isset($_POST['position']) ? sanitize_text_field($_POST['position']) : '';

        if($name == '') {
            echo json_encode(array('add'=>false, 'message'=>__('Field ID is mandatory.', 'listio')));
            exit();
        }
        if($label == '') {
            echo json_encode(array('add'=>false, 'message'=>__('Amenity label is mandatory.', 'listio')));
            exit();
        }

        if($position == '') {
            echo json_encode(array('add'=>false, 'message'=>__('Position is mandatory.', 'listio')));
            exit();
        }

        $var_name = str_replace(' ', '_', trim($name));

        $var_name = sanitize_key($name);

        $listio_amenity_settings                           = get_option('listio_amenity_settings');
        $listio_amenity_settings[$var_name]['name']        = $name;
        $listio_amenity_settings[$var_name]['label']       = $label;
        $listio_amenity_settings[$var_name]['image']       = $image;
        $listio_amenity_settings[$var_name]['icon']        = $icon;
        $listio_amenity_settings[$var_name]['position']    = $position;

        update_option('listio_amenity_settings', $listio_amenity_settings);

        echo json_encode(array('add'=>true));
        exit();

        die();
    }
endif;
add_action( 'wp_ajax_nopriv_listio_add_amenities', 'listio_add_amenities' );
add_action( 'wp_ajax_listio_add_amenities', 'listio_add_amenities' );

if( !function_exists('listio_delete_amenities') ): 
    function listio_delete_amenities () {
        check_ajax_referer('add_amenities_ajax_nonce', 'security');
        $amenity_name = isset($_POST['amenity_name']) ? sanitize_text_field($_POST['amenity_name']) : '';

        $listio_amenity_settings = get_option('listio_amenity_settings');
        unset($listio_amenity_settings[$amenity_name]);
        update_option('listio_amenity_settings', $listio_amenity_settings);

        echo json_encode(array('delete'=>true));
        exit();

        die();
    }
endif;
add_action( 'wp_ajax_nopriv_listio_delete_amenities', 'listio_delete_amenities' );
add_action( 'wp_ajax_listio_delete_amenities', 'listio_delete_amenities' );
?>